import java.awt.FlowLayout;
import java.util.Calendar;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.ParseException;
import java.util.Date;
import javax.swing.*;
import java.text.SimpleDateFormat;

public class AddJobFrame extends JFrame implements ActionListener {
	private static final long serialVersionUID = -3203528566766453562L;
	
	private Calendar cal = Calendar.getInstance();
	private Boolean ready;
	private JTextField appText;
	private JTextField argText;
	private JTextField pText;
	private JTextField bText;
	private JTextField deadlineText;
	private JTextField delayText;
	private String application;
	private String applicationArgs;
	private Date deadline;
	private int budget;
	private int delay = -1;
	private int priority;
	private GUI gui;
	private SimpleDateFormat format =
		new SimpleDateFormat("yyyy.MM.dd.HH.mm.ss");
	
	/**
	 * AddJobFrame Constructor.
	 * Sets the calling GUI and calls the initialise method.
	 * @param gui A reference to the GUI that created this object.
	 */
	public AddJobFrame(GUI gui) {
		this.gui = gui;
		initUI();
	}
	
	/**
	 * Creates and sets up the layout for this window.
	 */
	private void initUI() {
		this.setLayout(new FlowLayout());
		this.setTitle("Add Job");
		this.setSize(450, 160);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(getDefaultCloseOperation());
		
		JLabel appLabel = new JLabel("Enter the application name:");
		JLabel argLabel = new JLabel("Enter the arguments:");
		JLabel deadlineLabel = new JLabel("set deadline (yyyy.MM.dd.HH.mm.ss):");
		JLabel bLabel = new JLabel("set budget:");
		JLabel delayLabel = new JLabel("set delay:");
		JLabel pLabel = new JLabel("set priority:");
		JButton goButton = new JButton("Proceed");
		
		appText = new JTextField(20);
		argText = new JTextField(20);
		pText = new JTextField(2);
		bText = new JTextField(5);
		delayText = new JTextField(5);
		deadlineText = new JTextField(format.format(cal.getTime()));
		
		this.add(appLabel);
		this.add(appText);
		this.add(argLabel);
		this.add(argText);
		this.add(pLabel);
		this.add(pText);
		this.add(bLabel);
		this.add(bText);
		this.add(delayLabel);
		this.add(delayText);
		this.add(deadlineLabel);
		this.add(deadlineText);
		this.add(goButton);
		
		goButton.addActionListener(this);
		setVisible(true);
	}
	
	/**
	 * Invoked when an action occurs.
	 */
	@Override
	public void actionPerformed(ActionEvent event) {
		ready = true;
		
		try{
			application = appText.getText();
		} catch(Exception e) {
			JOptionPane.showMessageDialog((JFrame)this,
					"Application line error", "Warning",
					JOptionPane.WARNING_MESSAGE);
		}
		
		try{
			applicationArgs = argText.getText();
		} catch(Exception e) {
			JOptionPane.showMessageDialog((JFrame)this, "Argument line error",
					"Warning", JOptionPane.WARNING_MESSAGE);
		}
		
		try{
			budget = Integer.parseInt(bText.getText());
			if(budget < 0){
				JOptionPane.showMessageDialog((JFrame)this,
						"type in budget", "Warning",
						JOptionPane.WARNING_MESSAGE);
				ready = false;
			}
		} catch (Exception e) {
			JOptionPane.showMessageDialog((JFrame)this,
					"type in priority (1 - 10)", "Warning",
					JOptionPane.WARNING_MESSAGE);
		}
		
		try{
			priority = Integer.parseInt(pText.getText());
			if(priority < 0 || priority > 10){
				JOptionPane.showMessageDialog((JFrame)this,
						"type in priority (1 - 10)", "Warning",
						JOptionPane.WARNING_MESSAGE);
				ready = false;
			}
		} catch (Exception e) {
			JOptionPane.showMessageDialog((JFrame)this,
					"type in priority (1 - 10)", "Warning",
					JOptionPane.WARNING_MESSAGE);
		}
		
		try{
			delay = Integer.parseInt(delayText.getText());
		} catch (Exception e){
		}
		
		try {
			deadline = format.parse(deadlineText.getText());
			if (deadline.before(cal.getTime())){
				JOptionPane.showMessageDialog((JFrame)this,
						"enter a date that's in the future", "Warning",
						JOptionPane.WARNING_MESSAGE);
				ready = false;
			}
		} catch (ParseException e) {
			JOptionPane.showMessageDialog((JFrame)this, "please follow format",
					"Warning", JOptionPane.WARNING_MESSAGE);
			ready = false;
		}  
		
		if (ready == true){
			if (delay > 0) {
				gui.addJob(application, applicationArgs, deadline, budget,
						priority, new Date(new Date().getTime() + delay));
			} else {
				gui.addJob(application, applicationArgs, deadline, budget,
							priority);
			}
		}
	}
}