import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.*;

public class AlgorithmFrame extends JFrame implements ActionListener {
	private static final long serialVersionUID = 4384775146889678874L;
	
	private GUI gui;
	private JRadioButton firstComeRadio;
	private JRadioButton earliestFirstRadio;
	private JRadioButton earliestFirstBudgetRadio;
	
	/**
	 * AlgorithmFrame Constructor.
	 * Sets the calling GUI and calls the initialise method.
	 * @param gui A reference to the GUI that created this object.
	 */
	public AlgorithmFrame(GUI gui) {
		this.gui = gui;
		initUI();
	}
	
	/**
	 * Creates and sets up the layout for this window.
	 */
	private void initUI() {
		this.setLayout(new FlowLayout());
		this.setTitle("Choose Algorithm");
		this.setSize(450, 150);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(getDefaultCloseOperation());
		firstComeRadio = new JRadioButton("First Come First Served");
		earliestFirstRadio = new JRadioButton("Earliest Deadline First");
		earliestFirstBudgetRadio =
			new JRadioButton("Earliest Deadline First With Deadline Constraint");
		ButtonGroup group = new ButtonGroup();
		JButton goButton = new JButton("Proceed");
		group.add(firstComeRadio);
		group.add(earliestFirstRadio);
		group.add(earliestFirstBudgetRadio);
		add(firstComeRadio);
		add(earliestFirstRadio);
		add(earliestFirstBudgetRadio);
		add(goButton);
		setVisible(true);
		
		goButton.addActionListener(this);
	}
	
	/**
	 * Invoked when an action occurs.
	 */
	@Override
	public void actionPerformed(ActionEvent event) {
		if(firstComeRadio.isSelected()){
			gui.changeAlgorithm(JobManager.SchedulingAlgorithm.FIFO);
		}
		if(earliestFirstRadio.isSelected()){
			gui.changeAlgorithm(JobManager.SchedulingAlgorithm.EDF);
		}
		if(earliestFirstBudgetRadio.isSelected()){
			gui.changeAlgorithm(JobManager.SchedulingAlgorithm.EDCBB);
		}
		this.dispose();
	}
}