import java.util.ArrayList;
import javax.swing.table.AbstractTableModel;

public class ApplicationManager extends AbstractTableModel {
	private static final long serialVersionUID = -2966327999456086693L;
	
	private ArrayList<String> applicationList;
	private ArrayList<String> insList;
	
	/**
	 * ApplicationManager Constructor.
	 */
	public ApplicationManager() {
		applicationList = new ArrayList<String>();
		insList = new ArrayList<String>();
	}

	/**
	 * Adds a new application to the ArrayList of applications available for 
	 * running on the workers.
	 * @param newApplication The new application name to add.
	 */
	public void newApp(String newApplication) {
		applicationList.add(newApplication);
		fireTableRowsInserted(0, getRowCount() - 1);
	}

	/**
	 * Adds a new in file to the ArrayList of in files available for 
	 * using on the workers.
	 * @param newIn The new in file name to add.
	 */
	public void newIn(String newIn) {
		insList.add(newIn);
		fireTableRowsInserted(0, getRowCount() - 1);
	}
	
	/**
	 * Returns the number of columns in the model. A JTable uses this method to
	 * determine how many columns it should create and display.
     * @return The number of columns in the model.
	 */
	@Override
	public int getColumnCount() {
		return 3;
	}

	/**
	 * Returns the number of rows in the model.
	 * A JTable uses this method to determine how many rows it should display.
     * @return The number of rows in the model.
	 */
	@Override
	public int getRowCount() {
		return Math.max(applicationList.size(), insList.size());
	}

	/**
	 * Returns the value for the cell for a given row and column.
	 * @param row The row whose value is to be queried.
	 * @param col The column whose value is to be queried.
     * @return The value Object at the specified cell.
	 */
	@Override
	public Object getValueAt(int row, int col) {
		switch (col){
		case 0:
			if (row < applicationList.size())
				return applicationList.get(row);
			else
				return "";
		case 1:
			return "";
		case 2:
			if (row < insList.size())
				return insList.get(row);
			else
				return "";
		}
		throw new IllegalArgumentException("Bad cell (" + row + ", " + col +
											")");
	}
	
	/**
	 * Returns a name for the column.
	 * @param col The column being queried.
     * @return A string containing the name of column.
	 */
	@Override
	public String getColumnName(int col) {
		switch (col){
		case 0:
			return "Applications available";
		case 1:
			return "";
		case 2:
			return "In files available";
		}
		throw new IllegalArgumentException("Bad column (" + col + ")");
	}
}