import java.io.IOException;
import java.util.Scanner;

public class Master {
	private WorkerManager workers;
	private JobManager jobs;
	
	private boolean useGUI;
	private GUI gui;
	
	/**
	 * Master Constructor.
	 * Made default constructor private so that it can't be called
	 */
	@SuppressWarnings("unused")
	private Master() {
	}
	
	/**
	 * Master Constructor.
	 * Creates a new JobManager, WorkerManager and GUI. 
	 * @param useGUI If true display the GUI, else use a command-line.
	 */
	public Master(boolean useGUI) {
		this.useGUI = useGUI;
		
		jobs = new JobManager(5000);
		workers = new WorkerManager(jobs, 5000, 1000);
		
		gui = new GUI(workers, jobs);
		
		if (this.useGUI) {
			gui.setVisible(true);
		} else {
			doCommandLine();
			
			jobs.shutDown();
			workers.shutDown();
			
			jobs = null;
			workers = null;
			
			System.exit(0);
		}
	}
	
	/**
	 * Checks launch command-line options then creates a new Master.
	 * @param args Command-line arguments.
	 */
	public static void main(String[] args) {
		boolean useG = true;
		
		if (args.length > 0) {
			if (args[0].compareToIgnoreCase("nogui") == 0) {
				useG = false;
			} else {
				System.out.println("Program usage: java Master [nogui]");
				
				return;
			}
		}
		
		new Master(useG);
	}

	/**
	 * Basic command-line command parsing system.
	 */
	private void doCommandLine() {
		Scanner keyboard = new Scanner(System.in);
		String line = null;
		String helpText = "loadapplications\n" +
							"loadworkers\n" +
							"loadjobs\n" +
							"start\n" +
							"showworkers\n" +
							"showjobs\n" +
							"showapplications\n" +
							"changescheduling\n";
		
		System.out.println("Welcome to the Master.");
		System.out.println("Type \"help\" for a list of commands.");
		System.out.println("");
		System.out.print("> ");

		while (!(line = keyboard.nextLine()).equalsIgnoreCase("exit")) {
			if (line.equalsIgnoreCase("help")) {
				System.out.println(helpText);
			} else if (line.equalsIgnoreCase("loadapplications")) {
				try {
					gui.loadApplicationsFromFile("applications.txt");
					System.out.println("Applications successfully loaded.");
				} catch (IOException e) {
					e.printStackTrace();
				}
			} else if (line.equalsIgnoreCase("loadworkers")) {
				try {
					workers.clear();
					gui.loadWorkersFromFile("workers.txt");
					System.out.println("Workers successfully loaded.");
				} catch (IOException e) {
					e.printStackTrace();
				}
			} else if (line.equalsIgnoreCase("loadjobs")) {
				try {
					gui.loadJobsFromFile("jobs.txt");
					System.out.println("Jobs successfully loaded.");
				} catch (IOException e) {
					e.printStackTrace();
				}
			} else if (line.equalsIgnoreCase("start")) {
				workers.start();
				System.out.println("Computations started.");
			} else if (line.equalsIgnoreCase("showworkers")) {
				System.out.println(workers.toString());
			} else if (line.equalsIgnoreCase("showjobs")) {
				System.out.println(jobs.toString());
			} else if (line.equalsIgnoreCase("showapplications")) {
				System.out.println(workers.printExecs());
			} else if (line.equalsIgnoreCase("changescheduling")) {
				System.out.println("0: First Come First Served\n" +
									"1: Earliest Deadline First\n" +
									"2: Earliest Deadline First With Deadline" +
										" Constraint\n\n" +
									"Enter your choice > ");
				int sa = keyboard.nextInt();
				keyboard.nextLine();
				jobs.changeSchedulingAlgorithm(
						JobManager.SchedulingAlgorithm.values()[sa]);
			} else {
				System.out.println("Invalid command.");
			}
			
			System.out.print("> ");
		}
	}
}