import java.util.Comparator;

public class WorkerCostComparator implements Comparator<WorkerHandler> {
	
	/**
	 * Compares 2 WorkerHandlers by (time taken to complete a Job) * (cost).
	 * Because a Worker may not have completed a Job yet, it may not yet have
	 * a time and has its timeTaken variable set to -1. In this case, whichever
	 * Worker has a time set, it comes first or if neither have it set, use their
	 * ids to compare.
	 */
    public int compare(WorkerHandler x, WorkerHandler y) {
    	int  xcost = x.getCost();
    	int  ycost = y.getCost();
    	
    	int xtime = dtoi(x.getTimeTaken());
    	int ytime = dtoi(y.getTimeTaken());
    	
    	if ((xtime < 0) && (ytime < 0)) {
    		return (x.getId() - y.getId());
    	}
    	
    	if (ytime < 0) {
    		return -1;
    	} else if (xtime < 0) {
    		return 1;
    	}
    	
    	return (xcost * xtime) - (ycost * ytime);
    }
    
    /**
     * Converts a double to an int.
     * @param dbl double value.
     * @return int value.
     */
    private int dtoi(double dbl) {
    	return (new Double(dbl).intValue());
    }
}