import java.util.Comparator;

public class WorkerTimeComparator implements Comparator<WorkerHandler> {
	
	/**
	 * Compares 2 WorkerHandlers by the time taken to complete a Job.
	 * Because a Worker may not have completed a Job yet, it may not yet have
	 * a time and has its timeTaken variable set to -1. In this case, whichever
	 * Worker has a time set, it comes first or if neither have it set, use their
	 * ids to compare.
	 */
    public int compare(WorkerHandler x, WorkerHandler y) {
    	long xtime = x.getTimeTaken();
    	long ytime = y.getTimeTaken();
    	
    	if ((xtime < 0) && (ytime < 0)) {
    		return (x.getId() - y.getId());
    	}
    	
    	if (ytime < 0) {
    		return -1;
    	} else if (xtime < 0) {
    		return 1;
    	}
    	
    	return (new Double(xtime - ytime)).intValue();
    }
}