import java.io.*;

public class Job extends Thread {
	int status, id;
	Process proc;
	String app, args, out;
	
	/**
	 * Constructor for Job. A thread which is run to execute a external application
	 * @param id	ID of the job for reference by the Worker
	 * @param app	Name of the application to be run
	 * @param args	Arguments to be passed to the application
	 * @param out	Output filename that is to be written to
	 */
	public Job(int id, String app, String args, String out) {
		this.id = id;
		this.status = 0;
		this.app = app;
		this.args = args;
		this.out = out;
		
		this.proc = null;
	}
	
	/**
	 * 	Run method. Takes the initialised variables and runs the application with arguments. 
	 *  Opens a new redirect thread to write the application's output to an output file.
	 */
	public void run() {		
		try {
			if (this.status < 0) {
				throw new IOException("No Job Availiable.");
			}
			
			String run = this.app + " " + this.args;
			Runtime rt = Runtime.getRuntime();
			
			FileOutputStream fos = new FileOutputStream(out);
			
			System.out.println("> Job #" + id + " Started - Running '" + run + "'");
			this.status = 1;
			proc = rt.exec("java -jar " + run);
			
			StreamRedirect sr = new StreamRedirect(proc.getInputStream(), fos);
			sr.start();
			
			System.out.println("> Job Complete (Exit Code: " + proc.waitFor() + ")");
			this.status = 2;
			
			fos.flush();
			fos.close();
			
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * 	Stops the current job running by destroying the process running it.
	 */
	public void stopJob() {
		if (this.status == 1) {
			System.out.println("> Job Aborted");
			proc.destroy();
		}
	}
	
	/**
	 * 	Getter for status of the job
	 * @return Status of the job (-1 Error, 0 Waiting, 1 Busy, 2 Finished)
	 */
	public int getStatus() {
		return this.status;
	}
}
